@@ -19,6 +19,7 @@
  */
 package com.eteks.textureslibraryeditor.model;
 
+import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
 
 import com.eteks.sweethome3d.model.LengthUnit;
@@ -30,18 +31,20 @@ import com.eteks.sweethome3d.model.UserPreferences;
  */
 public abstract class TexturesLibraryUserPreferences extends UserPreferences {
   /**
-   * The properties of user preferences that may change. <code>PropertyChangeListener</code>s added 
+   * The properties of user preferences that may change. <code>PropertyChangeListener</code>s added
    * to user preferences will be notified under a property name equal to the string value of one these properties.
    */
   public enum Property {DEFAULT_CREATOR, OFFLINE_TEXTURES_LIBRARY, TEXTURES_RESOURCES_LOCAL_DIRECTORY,
-                        TEXTURES_RESOURCES_REMOTE_URL_BASE}
-  
+                        TEXTURES_RESOURCES_REMOTE_URL_BASE, TEXTURES_ID_EDITABLE, CONTENT_MATCHING_TEXTURES_NAME}
+
   private final PropertyChangeSupport propertyChangeSupport;
   private String [] editedProperties;
   private String    defaultCreator;
   private boolean   offlineTexturesLibrary;
   private String    texturesResourcesLocalDirectory;
   private String    texturesResourcesRemoteUrlBase;
+  private boolean   texturesIdEditable;
+  private boolean   contentMatchingTexturesName;
 
   public TexturesLibraryUserPreferences() {
     this.propertyChangeSupport = new PropertyChangeSupport(this);
@@ -54,14 +57,52 @@ public abstract class TexturesLibraryUserPreferences extends UserPreferences {
         TexturesLibrary.TEXTURES_HEIGHT_PROPERTY};
     setUnit(LengthUnit.CENTIMETER);
     this.offlineTexturesLibrary = true;
+    this.contentMatchingTexturesName = true;
   }
 
   @Override
   public String [] getSupportedLanguages() {
     return new String [] {"en", "fr"};
   }
-  
+
   /**
+   * Adds the property change <code>listener</code> in parameter to these preferences.
+   */
+  public void addPropertyChangeListener(PropertyChangeListener listener) {
+    super.addPropertyChangeListener(listener);
+    this.propertyChangeSupport.addPropertyChangeListener(listener);
+  }
+
+  /**
+   * Removes the property change <code>listener</code> in parameter from these preferences.
+   */
+  public void removePropertyChangeListener(PropertyChangeListener listener) {
+    this.propertyChangeSupport.removePropertyChangeListener(listener);
+    super.removePropertyChangeListener(listener);
+  }
+
+  /**
+   * Adds the <code>listener</code> in parameter to these preferences to listen
+   * to the changes of the given <code>property</code>.
+   * <br>Caution: a user preferences instance generally exists during all the application ;
+   * therefore you should take care of not bounding permanently listeners to this
+   * object (for example, do not create anonymous listeners on user preferences
+   * in classes depending on an edited home).
+   */
+  public void addPropertyChangeListener(Property property,
+                                        PropertyChangeListener listener) {
+    this.propertyChangeSupport.addPropertyChangeListener(property.name(), listener);
+  }
+
+  /**
+   * Removes the <code>listener</code> in parameter from these preferences.
+   */
+  public void removePropertyChangeListener(Property property,
+                                           PropertyChangeListener listener) {
+    this.propertyChangeSupport.removePropertyChangeListener(property.name(), listener);
+  }
+
+ /**
    * Returns the language used to retrieve the default localized values of the textures.
    */
   public String getTexturesDefaultLanguage() {
@@ -74,14 +115,14 @@ public abstract class TexturesLibraryUserPreferences extends UserPreferences {
   public String [] getEditedProperties() {
     return this.editedProperties;
   }
-  
+
   /**
    * Returns the creator used by default for imported textures or <code>null</code>.
    */
   public String getDefaultCreator() {
     return this.defaultCreator;
   }
-  
+
   /**
    * Sets the creator used by default for imported textures.
    */
@@ -90,28 +131,28 @@ public abstract class TexturesLibraryUserPreferences extends UserPreferences {
         || defaultCreator != null && !defaultCreator.equals(this.defaultCreator)) {
       String oldDefaultCreator = this.defaultCreator;
       this.defaultCreator = defaultCreator;
-      this.propertyChangeSupport.firePropertyChange(Property.DEFAULT_CREATOR.toString(), oldDefaultCreator, defaultCreator);
+      this.propertyChangeSupport.firePropertyChange(Property.DEFAULT_CREATOR.name(), oldDefaultCreator, defaultCreator);
     }
   }
 
   /**
    * Returns <code>true</code> if the user may edit online libraries,
-   * and sets textures resources local directory and remote URL base.   
+   * and sets textures resources local directory and remote URL base.
    */
   public boolean isOnlineTexturesLibrarySupported() {
     return false;
   }
-  
+
   /**
-   * Returns <code>true</code> if resources needed by the textures of a library 
-   * must be included with the library to let it work without connection. 
+   * Returns <code>true</code> if resources needed by the textures of a library
+   * must be included with the library to let it work without connection.
    */
   public boolean isTexturesLibraryOffline() {
     return this.offlineTexturesLibrary;
   }
-  
+
   /**
-   * Sets whether resources needed by the textures of a library 
+   * Sets whether resources needed by the textures of a library
    * must be included with the library to let it work without connection or not.
    */
   public void setTexturesLibraryOffline(boolean offlineTexturesLibrary) {
@@ -120,7 +161,7 @@ public abstract class TexturesLibraryUserPreferences extends UserPreferences {
     }
     if (offlineTexturesLibrary != this.offlineTexturesLibrary) {
       this.offlineTexturesLibrary = offlineTexturesLibrary;
-      this.propertyChangeSupport.firePropertyChange(Property.OFFLINE_TEXTURES_LIBRARY.toString(), 
+      this.propertyChangeSupport.firePropertyChange(Property.OFFLINE_TEXTURES_LIBRARY.name(),
           !offlineTexturesLibrary, offlineTexturesLibrary);
     }
   }
@@ -132,7 +173,7 @@ public abstract class TexturesLibraryUserPreferences extends UserPreferences {
   public String getTexturesResourcesLocalDirectory() {
     return this.texturesResourcesLocalDirectory;
   }
-  
+
   /**
    * Sets the local directory where resources needed by the textures of a library
    * will be saved before being deployed on server.
@@ -145,23 +186,23 @@ public abstract class TexturesLibraryUserPreferences extends UserPreferences {
         || texturesResourcesLocalDirectory != null && !texturesResourcesLocalDirectory.equals(this.texturesResourcesLocalDirectory)) {
       String oldValue = this.texturesResourcesLocalDirectory;
       this.texturesResourcesLocalDirectory = texturesResourcesLocalDirectory;
-      this.propertyChangeSupport.firePropertyChange(Property.TEXTURES_RESOURCES_LOCAL_DIRECTORY.toString(),
+      this.propertyChangeSupport.firePropertyChange(Property.TEXTURES_RESOURCES_LOCAL_DIRECTORY.name(),
           oldValue, texturesResourcesLocalDirectory);
     }
   }
 
   /**
-   * Returns the URL base (relative or absolute) used to build the path to resources 
-   * needed by the textures of a library. 
+   * Returns the URL base (relative or absolute) used to build the path to resources
+   * needed by the textures of a library.
    */
   public String getTexturesResourcesRemoteURLBase() {
     return this.texturesResourcesRemoteUrlBase;
   }
-  
+
   /**
-   * Sets the URL base (relative or absolute) used to build the path to resources 
+   * Sets the URL base (relative or absolute) used to build the path to resources
    * needed by the textures of a library. This base should be ended by a / character
-   * if it's a directory. 
+   * if it's a directory.
    */
   public void setTexturesResourcesRemoteURLBase(String texturesResourcesRemoteUrlBase) {
     if (!isOnlineTexturesLibrarySupported()) {
@@ -171,17 +212,45 @@ public abstract class TexturesLibraryUserPreferences extends UserPreferences {
         || texturesResourcesRemoteUrlBase != null && !texturesResourcesRemoteUrlBase.equals(this.texturesResourcesRemoteUrlBase)) {
       Object oldValue = this.texturesResourcesRemoteUrlBase;
       this.texturesResourcesRemoteUrlBase = texturesResourcesRemoteUrlBase;
-      this.propertyChangeSupport.firePropertyChange(Property.TEXTURES_RESOURCES_REMOTE_URL_BASE.toString(),
+      this.propertyChangeSupport.firePropertyChange(Property.TEXTURES_RESOURCES_REMOTE_URL_BASE.name(),
           oldValue, texturesResourcesRemoteUrlBase);
     }
   }
 
   /**
-   * Returns <code>true</code> if the textures content saved with the library should be named 
+   * Returns <code>true</code> if texture ids are editable.
+   */
+  public boolean isTexturesIdEditable() {
+    return this.texturesIdEditable;
+  }
+
+  /**
+   * Sets whether texture ids are editable.
+   */
+  public void setTexturesIdEditable(boolean texturesIdEditable) {
+    if (texturesIdEditable != this.texturesIdEditable) {
+      this.texturesIdEditable = texturesIdEditable;
+      this.propertyChangeSupport.firePropertyChange(Property.TEXTURES_ID_EDITABLE.name(), !texturesIdEditable, texturesIdEditable);
+    }
+  }
+
+  /**
+   * Returns <code>true</code> if the texture content saved with the library should be named
    * from the textures name in the default language.
    */
   public boolean isContentMatchingTexturesName() {
-    return true;
+    return this.contentMatchingTexturesName;
+  }
+
+  /**
+   * Sets whether the texture content saved with the library should be named
+   * from the textures name in the default language.
+   */
+  public void setContentMatchingTexturesName(boolean contentMatchingTexturesName) {
+    if (contentMatchingTexturesName != this.contentMatchingTexturesName) {
+      this.contentMatchingTexturesName = contentMatchingTexturesName;
+      this.propertyChangeSupport.firePropertyChange(Property.CONTENT_MATCHING_TEXTURES_NAME.name(), !contentMatchingTexturesName, contentMatchingTexturesName);
+    }
   }
 
   /**
